]> git.saurik.com Git - bison.git/commitdiff
* src/LR0.c (new_itemsets): Use nshifts only, not shiftcount.
authorAkim Demaille <akim@epita.fr>
Wed, 5 Dec 2001 09:41:01 +0000 (09:41 +0000)
committerAkim Demaille <akim@epita.fr>
Wed, 5 Dec 2001 09:41:01 +0000 (09:41 +0000)
* src/closure.c, src/closure.h (itemsetsize): Rename as...
(nitemset): for consistency with the rest of the project.

ChangeLog
src/LR0.c
src/closure.c
src/closure.h

index 5f3544782a397d7296d3e9855ed4f76c211b8bd8..e70da665c4644a14ca1fa636ebc16e81db1d288c 100644 (file)
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,10 @@
+2001-12-05  Akim Demaille  <akim@epita.fr>
+
+       * src/LR0.c (new_itemsets): Use nshifts only, not shiftcount.
+       * src/closure.c, src/closure.h (itemsetsize): Rename as...
+       (nitemset): for consistency with the rest of the project.
+
+       
 2001-12-05  Akim Demaille  <akim@epita.fr>
 
        * src/closure.c (print_closure): Improve.
index f8fa5bd0c15b564aee15c7bbd64fdfc6f44b2c95..3fa5ba5bda947b1bf76a52e0ece86e5d1126f681 100644 (file)
--- a/src/LR0.c
+++ b/src/LR0.c
@@ -141,7 +141,6 @@ static void
 new_itemsets (void)
 {
   int i;
-  int shiftcount;
 
   if (trace_flag)
     fprintf (stderr, "Entering new_itemsets, state = %d\n",
@@ -151,25 +150,23 @@ new_itemsets (void)
     kernel_size[i] = 0;
 
   shift_symbol = XCALLOC (short, nsyms);
-  shiftcount = 0;
+  nshifts = 0;
 
-  for (i = 0; i < itemsetsize; ++i)
+  for (i = 0; i < nitemset; ++i)
     {
       int symbol = ritem[itemset[i]];
       if (symbol > 0)
        {
          if (!kernel_size[symbol])
            {
-             shift_symbol[shiftcount] = symbol;
-             shiftcount++;
+             shift_symbol[nshifts] = symbol;
+             nshifts++;
            }
 
          kernel_base[symbol][kernel_size[symbol]] = itemset[i] + 1;
          kernel_size[symbol]++;
        }
     }
-
-  nshifts = shiftcount;
 }
 
 
@@ -542,7 +539,7 @@ save_reductions (void)
   /* Find and count the active items that represent ends of rules. */
 
   count = 0;
-  for (i = 0; i < itemsetsize; ++i)
+  for (i = 0; i < nitemset; ++i)
     {
       int item = ritem[itemset[i]];
       if (item < 0)
index ed35c730fc438fec8e29693dd24526f47b09c7d4..77ca72c8f1846880a6dd09aacdfa2fb4e567086c 100644 (file)
@@ -26,9 +26,9 @@
 #include "derives.h"
 #include "warshall.h"
 
/* ITEMSETSIZE is the size of the array ITEMSET.  */
 short *itemset;
-int itemsetsize;
+int nitemset;
 
 static unsigned *ruleset;
 
@@ -218,7 +218,7 @@ closure (short *core, int n)
            ruleset[r] |= FDERIVES (ritem[core[c]])[r];
     }
 
-  itemsetsize = 0;
+  nitemset = 0;
   c = 0;
   for (ruleno = 0; ruleno < rulesetsize * BITS_PER_WORD; ++ruleno)
     if (BITISSET (ruleset, ruleno))
@@ -226,23 +226,23 @@ closure (short *core, int n)
        int itemno = rule_table[ruleno].rhs;
        while (c < n && core[c] < itemno)
          {
-           itemset[itemsetsize] = core[c];
-           itemsetsize++;
+           itemset[nitemset] = core[c];
+           nitemset++;
            c++;
          }
-       itemset[itemsetsize] = itemno;
-       itemsetsize++;
+       itemset[nitemset] = itemno;
+       nitemset++;
       }
 
   while (c < n)
     {
-      itemset[itemsetsize] = core[c];
-      itemsetsize++;
+      itemset[nitemset] = core[c];
+      nitemset++;
       c++;
     }
 
   if (trace_flag)
-    print_closure ("output", itemset, itemsetsize);
+    print_closure ("output", itemset, nitemset);
 }
 
 
index 887f3da86ec61f4e87d6d56d39ffd620a4315b34..fdf4cc5e8fd7b462ad03df14ba47e4b93b519655 100644 (file)
 void new_closure PARAMS ((int n));
 
 
-/* Given a vector of item numbers ITEMS, of length N, set up ruleset
-   and itemset to indicate what rules could be run and which items
-   could be accepted when those items are the active ones.
+/* Given the kernel (aka core) of a state (a vector of item numbers
+   ITEMS, of length N), set up ruleset and itemset to indicate what
+   rules could be run and which items could be accepted when those
+   items are the active ones.
 
    ruleset contains a bit for each rule.  closure sets the bits for
    all rules which could potentially describe the next input to be
    read.
 
-   itemset is a vector of item numbers; itemsetend points to just
-   beyond the end of the part of it that is significant.  closure
-   places there the indices of all items which represent units of
-   input that could arrive next.  */
+   ITEMSET is a vector of item numbers; NITEMSET is its size
+   9actually, points to just beyond the end of the part of it that is
+   significant).  closure places there the indices of all items which
+   represent units of input that could arrive next.  */
 
 void closure PARAMS ((short *items, int n));
 
@@ -51,6 +52,6 @@ void closure PARAMS ((short *items, int n));
 void free_closure PARAMS ((void));
 
 extern short *itemset;
-extern int itemsetsize;
+extern int nitemset;
 
 #endif /* !CLOSURE_H_ */
@@ -26,9 +26,9 @@
 #include "warshall.h"
 
-/* ITEMSETSIZE is the size of the array ITEMSET.  */
+/* NITEMSET is the size of the array ITEMSET.  */
 short *itemset;